Test Refresh
open | ../tests/html/test_page.slow.html |
verifyLocation | */tests/html/test_page.slow.html |
verifyTitle | Slow Loading Page |

Change the text dynamically, then refresh to make sure the text reverts

click | changeSpan |
assertTextPresent | Changed the text |
refreshAndWait |  |
assertTextNotPresent | Changed the text |

Change the text dynamically again, then click on a button to do a slow refresh

click | changeSpan |
assertTextPresent | Changed the text |
clickAndWait | slowRefresh |
assertTextNotPresent | Changed the text |

And again with an anchor in the URL

click | anchor |
click | changeSpan |
assertTextPresent | Changed the text |
refreshAndWait |  |
assertTextNotPresent | Changed the text |